@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -41,18 +41,25 @@
 
 ;;{{{  introduction
 
-;;; Commentary: BBC: http://www.bbc.co.uk This module uses
+;;; Commentary:
+;;; BBC: http://www.bbc.co.uk
+;;; This module uses
 ;;; publicly available REST APIs to implement a native Emacs
 ;;; client for browsing and listening to BBC programs.
 
 ;;; See http://www.bbc.co.uk/programmes/developers
 ;;; The BBC API helps locate a PID for a given program stream.
-;;; That PID is converted to a streamable URL via the convertor:
-;;; http://www.iplayerconverter.co.uk/convert.aspx
-;;;Conversion: http://www.iplayerconverter.co.uk/convert.aspx?pid=%s
-;;; The result of the above conversion gives a Web page with a
-;;; set of links,
-;;; We hand the link to the raw stream  to mplayer.
+;;; We then construct the BBC IPlayer URL for that  PID,
+;;; And either hand that link off to Chrome,
+;;; Or stream it via get_iplayer and mplayer.
+;;; get_iplayer: https://github.com/get-iplayer/get_iplayer.git
+;;; get_player vs Chrome: Pro/Con:
+;;; Chrome: Has the UI for seeking in the stream.
+;;; get_iplayer: We use a named pipe, and cannot seek,
+;;; but the rest of emacspeak-m-player is available.
+;;; For downloading a program etc., use Emacs package iplayer.
+
+;;; Code:
 
 ;;}}}
 ;;{{{  Required modules
@@ -66,24 +73,23 @@
 
 ;;}}}
 ;;{{{ Helpers:
+
 (defvar emacspeak-bbc-json nil
   "Buffer local variable to store API results.")
 (make-variable-buffer-local 'emacspeak-bbc-json)
+
 (defvar emacspeak-bbc-json-schedules-template
   "http://www.bbc.co.uk/%s/programmes/schedules/%s%s.json"
   "URL template for pulling schedules as json.")
 
-(defvar emacspeak-bbc-iplayer-convertor
-  "http://www.iplayerconverter.co.uk/convert.aspx?pid=%s"
-  "REST API for converting IPlayer program-id to  stream.")
-
 (defun emacspeak-bbc-read-schedules-url ()
   "Return URL for schedule for specified station, outlet, date.
 Date defaults to today."
   (declare  (special emacspeak-bbc-json-schedules-template
                      emacspeak-bbc-station-list))
   (let* ((fields (split-string
-                  (completing-read  "Station:Outlet:" emacspeak-bbc-station-list)
+                  (completing-read "Station:Outlet:" emacspeak-bbc-station-list
+                                   nil 'must-match)
                   ":"))
          (date (emacspeak-speak-read-date-year/month/date))
          (station (first fields))
@@ -100,8 +106,7 @@ Date defaults to today."
 (defun emacspeak-bbc-read-genre-url ()
   "Return URL for specified  genre."
   (declare (special emacspeak-bbc-json-genre-template))
-  (let
-      ((genre (read-from-minibuffer "Genre/Genre/Genre:")))
+  (let ((genre (read-from-minibuffer "Genre/Genre/Genre:")))
     (format emacspeak-bbc-json-genre-template genre)))
 
 (defvar emacspeak-bbc-station-list
@@ -191,8 +196,97 @@ Date defaults to today."
     "radiocymru")
   "List of BBC Radio stations.")
 
+;;}}}
+;;{{{ Stream using get_iplayer:
+
+(defvar emacspeak-bbc-iplayer-handle "/tmp/iplayer-stream.mp3"
+  "Location of named pipe used for streaming.")
+
+(defcustom emacspeak-bbc-get-iplayer (executable-find "get_iplayer")
+  "Name of get_iplayer executable."
+  :type 'string
+  :group 'emacspeak-bbc)
+
+(defun emacspeak-bbc-get-iplayer-action (button)
+  "Stream using get_iplayer."
+  (declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
+  (let
+      ((command
+        (format
+         "%s --stream --pid=%s --modes=flashaaclow,hlsaaclow --type=radio > %s &"
+         emacspeak-bbc-get-iplayer
+         (button-get button 'pid) emacspeak-bbc-iplayer-handle)))
+    (unless (file-exists-p emacspeak-bbc-iplayer-handle)
+      (shell-command (format "mknod %s p" emacspeak-bbc-iplayer-handle)))
+    (dtk-speak-and-echo "Initialized stream, please wait.")
+    (shell-command  command " *get-iplayer*")
+    (sit-for 1)
+    (emacspeak-m-player emacspeak-bbc-iplayer-handle)))
+;;;###autoload
+(defun emacspeak-bbc-get-iplayer-stream-url (url)
+  "Stream using get_iplayer."
+  (interactive "sURL: ")
+  (declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
+  (let
+      ((command
+        (format
+         "%s --stream --url='%s' --modes=flashaaclow,hlsaaclow --type=radio > %s &"
+         emacspeak-bbc-get-iplayer url emacspeak-bbc-iplayer-handle)))
+    (unless (file-exists-p emacspeak-bbc-iplayer-handle)
+      (shell-command (format "mknod %s p" emacspeak-bbc-iplayer-handle)))
+    (dtk-speak-and-echo "Initialized stream, please wait.")
+    (shell-command  command " *get-iplayer*")
+    (sit-for 1)
+    (emacspeak-m-player emacspeak-bbc-iplayer-handle)))
+
+;;;###autoload
+(defun emacspeak-bbc-get-iplayer-stream-pid (pid)
+  "Stream using get_iplayer."
+  (interactive "sURL: ")
+  (declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
+  (let
+      ((command
+        (format
+         "%s --stream --pid='%s' --modes=flashaaclow,hlsaaclow --type=radio > %s &"
+         emacspeak-bbc-get-iplayer pid emacspeak-bbc-iplayer-handle)))
+    (unless (file-exists-p emacspeak-bbc-iplayer-handle)
+      (shell-command (format "mknod %s p" emacspeak-bbc-iplayer-handle)))
+    (dtk-speak-and-echo "Initialized stream, please wait.")
+    (shell-command  command " *get-iplayer*")
+    (sit-for 1)
+    (emacspeak-m-player emacspeak-bbc-iplayer-handle)))
+
+;;}}}
+;;{{{ Stream Using Chrome:
+
+(defun emacspeak-bbc-chrome-action (button)
+  "Play program  refered to by this button."
+  (browse-url-chromium (button-get  button 'link)))
+
+;;}}}
+;;{{{ Generic Button Action:
+
+(defcustom emacspeak-bbc-button-action
+  (if (executable-find "get_iplayer") 'get-iplayer 'chrome)
+  "Action to use for BBC iPlayer buttons.
+get-iplayer: use get_iplayer.
+chrome: Hand off URL to Chrome."
+  :type '(choice :tag "Player"
+                 (const :tag "Use get_iplayer"  get-iplayer)
+                 (const :tag "Use chrome"  chrome))
+  :group 'emacspeak-bbc)
+
+(defun emacspeak-bbc-iplayer-button-action (button)
+  "Generic button action that dispatches to get_iplayer or chrome based
+on user preference."
+  (declare (special emacspeak-bbc-button-action))
+  (ecase emacspeak-bbc-button-action
+    ('chrome (funcall #'emacspeak-bbc-chrome-action button))
+    ('get-iplayer (funcall #'emacspeak-bbc-get-iplayer-action button))))
+
 ;;}}}
 ;;{{{ BBC IPlayer Interaction
+
 ;;;###autoload
 (defun emacspeak-bbc (&optional genre)
   "Launch BBC Interaction.
@@ -255,11 +349,17 @@ Interactive prefix arg filters  content by genre."
   'help-echo "Play Program"
   'action #'emacspeak-bbc-iplayer-button-action)
 
+(defvar emacspeak-bbc-iplayer-uri-prefix
+  "http://www.bbc.co.uk/radio/player/"
+  "URL end-point for iplayer.")
+
 (defun   emacspeak-bbc-insert-show (show)
   "Insert a formatted button for this show."
+  (declare (special emacspeak-bbc-iplayer-uri-prefix))
   (let ((title  (g-json-lookup-string "programme.display_titles.title" show))
         (pid (g-json-lookup-string "programme.pid" show))
-        (short-title (g-json-lookup-string "programme.display_titles.subtitle" show))
+        (short-title
+         (g-json-lookup-string "programme.display_titles.subtitle" show))
         (start (g-json-get 'start show))
         (synopsis (g-json-lookup-string "programme.short_synopsis" show))
         (orig (point)))
@@ -267,26 +367,12 @@ Interactive prefix arg filters  content by genre."
     (insert-text-button
      (format "%s %s" title short-title); label
      'type 'emacspeak-bbc-iplayer-button
+     'link (concat emacspeak-bbc-iplayer-uri-prefix pid)
      'pid pid)
     (insert (format "\t%s\n" start))
     (insert (format "%s" synopsis))
     (put-text-property  orig (point) 'show show)))
 
-(defun emacspeak-bbc-iplayer-button-action (button)
-  "Play program  refered to by this button."
-  (declare (special emacspeak-bbc-iplayer-convertor))
-  (add-hook
-   'emacspeak-web-post-process-hook
-   #'(lambda nil
-       (cond
-        ((search-forward "mms:" nil t)
-         (emacspeak-webutils-play-media-at-point)
-         (bury-buffer))
-        (t (message "Could not find media link."))))
-   'at-end)
-  (browse-url
-   (format emacspeak-bbc-iplayer-convertor (button-get button 'pid))))
-
 ;;}}}
 (provide 'emacspeak-bbc)
 ;;{{{ end of file
