@@ -49,134 +49,134 @@
 ;;; Code:
 ;;}}}
 ;;{{{  bookmarks
-(defadvice bookmark-set (after emacspeak pre act)
+(defadvice bookmark-set (after emacspeak pre act comp)
   "Announce yourself."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (message "Set bookmark ")))
 
-(defadvice bookmark-yank-word (after emacspeak pre act )
+(defadvice bookmark-yank-word (after emacspeak pre act)
   "Speak what has been yanked so far"
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'yank-object )
-    (emacspeak-speak-line )))
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'yank-object)
+    (emacspeak-speak-line)))
 
-(defadvice bookmark-insert-current-bookmark (after emacspeak pre act )
+(defadvice bookmark-insert-current-bookmark (after emacspeak pre act)
   "Speak what has been yanked so far"
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'yank-object )
-    (emacspeak-speak-line )))
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'yank-object)
+    (emacspeak-speak-line)))
 
-(defadvice bookmark-insert-current-file-name (after emacspeak pre act )
+(defadvice bookmark-insert-current-file-name (after emacspeak pre act)
   "Speak what has been yanked so far"
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'yank-object )
-    (emacspeak-speak-line )))
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'yank-object)
+    (emacspeak-speak-line)))
 
-(defadvice  bookmark-jump (after emacspeak pre act)
+(defadvice  bookmark-jump (after emacspeak pre act comp)
   "Announce what happened."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-speak-line )))
+    (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-list (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (switch-to-buffer "*Bookmark List*")
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-this-window (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'open-object)))
 (defadvice bookmark-bmenu-select (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 (defadvice bookmark-bmenu-delete-backwards (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-1-window (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-2-window (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-switch-other-window (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-edit-annotation (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bookmark-bmenu-delete (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-unmark (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-speak-line)
     ))
 
 (defadvice bookmark-bmenu-edit-annotation (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice bookmark-send-edited-annotation (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-show-annotation (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-other-window 1)))
 
 (defadvice bookmark-bmenu-show-all-annotations (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Displayed all annotations in other window")))
 
 (defadvice bookmark-bmenu-mark (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-speak-line)))
 
 (defadvice bookmark-bmenu-quit  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bookmark-bmenu-backup-unmark (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-speak-line)))
 
