@@ -4,7 +4,7 @@
 
 (put 'accessibility 'custom-loads '(emacspeak))
 (put 'amixer 'custom-loads '(amixer))
-(put 'applications 'custom-loads '(emacspeak sox xbacklight))
+(put 'applications 'custom-loads '(emacspeak soundscape sox xbacklight))
 (put 'cd-tool 'custom-loads '(cd-tool))
 (put 'dtk 'custom-loads '(dtk-speak))
 (put 'dtk-unicode 'custom-loads '(dtk-unicode))
@@ -18,6 +18,7 @@
 (put 'emacspeak-dbus 'custom-loads '(nm))
 (put 'emacspeak-dired 'custom-loads '(emacspeak-dired))
 (put 'emacspeak-dismal 'custom-loads '(emacspeak-dismal))
+(put 'emacspeak-eldoc 'custom-loads '(emacspeak-advice))
 (put 'emacspeak-eperiodic 'custom-loads '(emacspeak-eperiodic))
 (put 'emacspeak-epub 'custom-loads '(emacspeak-epub))
 (put 'emacspeak-erc 'custom-loads '(emacspeak-erc))
@@ -29,6 +30,7 @@
 (put 'emacspeak-feeds 'custom-loads '(emacspeak-feeds))
 (put 'emacspeak-forms 'custom-loads '(emacspeak-forms))
 (put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
+(put 'emacspeak-google 'custom-loads '(emacspeak-google))
 (put 'emacspeak-hide 'custom-loads '(emacspeak-hide))
 (put 'emacspeak-info 'custom-loads '(emacspeak-info))
 (put 'emacspeak-ispell 'custom-loads '(emacspeak-ispell))
@@ -55,6 +57,7 @@
 (put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
 (put 'emacspeak-we 'custom-loads '(emacspeak-we))
 (put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
+(put 'emacspeak-webspace 'custom-loads '(emacspeak-webspace))
 (put 'emacspeak-webutils 'custom-loads '(emacspeak-webutils))
 (put 'emacspeak-wizards 'custom-loads '(emacspeak-wizards))
 (put 'emacspeak-xml-shell 'custom-loads '(emacspeak-xml-shell))
@@ -68,6 +71,7 @@
 (put 'gnus 'custom-loads '(emacspeak-gnus))
 (put 'isearch 'custom-loads '(emacspeak-replace))
 (put 'message 'custom-loads '(emacspeak-message))
+(put 'soundscape 'custom-loads '(soundscape))
 (put 'sox 'custom-loads '(sox))
 (put 'speedbar 'custom-loads '(emacspeak-speedbar))
 (put 'tetris 'custom-loads '(tetris))
