@@ -75,7 +75,6 @@
 ;;; by pressing the Pianobar prefix key (@code{C-e '}) followed by
 ;;; keys from @code{pianobar-key-map}.
 
-
 ;;; Code:
 
 ;;}}}
@@ -107,26 +106,29 @@
 (defun emacspeak-pianobar-volume-down ()
   "Decrease volume"
   (interactive)
-   (pianobar-send-string "(\n"))
-
+  (pianobar-send-string "(\n"))
 
 (defun emacspeak-pianobar-volume-up ()
   "Increase volume"
   (interactive)
-   (pianobar-send-string ")\n"))
+  (pianobar-send-string ")\n"))
 (defadvice pianobar (after emacspeak pre act comp)
   "Provide auditory feedback."
   (with-current-buffer pianobar-buffer
     (define-key pianobar-key-map "t" 'emacspeak-pianobar-electric-mode-toggle)
     (define-key pianobar-key-map [right] 'pianobar-next-song)
     (dotimes (i 10)
-      (define-key pianobar-key-map    (format "%s" i )   'emacspeak-pianobar-switch-to-preset ))
+      (define-key pianobar-key-map    (format "%s" i)   'emacspeak-pianobar-switch-to-preset))
     (dotimes (i 25)
       (define-key pianobar-key-map
         (format "%c" (+ i 65))
-        'emacspeak-pianobar-switch-to-preset ))
+        'emacspeak-pianobar-switch-to-preset))
     (define-key  pianobar-key-map [up] 'emacspeak-pianobar-previous-preset)
     (define-key  pianobar-key-map [down] 'emacspeak-pianobar-next-preset)
+    (define-key  pianobar-key-map "," 'emacspeak-pianobar-previous-preset)
+    (define-key  pianobar-key-map [down]".")
+    (define-key  pianobar-key-map "<" 'emacspeak-pianobar-previous-preset)
+    (define-key  pianobar-key-map">" 'emacspeak-pianobar-next-preset)
     (define-key pianobar-key-map "("
       'emacspeak-pianobar-volume-down)
     (define-key pianobar-key-map [prior] 'emacspeak-pianobar-volume-down)
@@ -155,11 +157,11 @@
       (eval
        `(defadvice ,f (before emacspeak pre act comp)
           "Play auditory icon."
-          (when (ems-interactive-p )
+          (when (ems-interactive-p)
             (emacspeak-auditory-icon 'select-object)))))
 (defadvice pianobar-window-toggle (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (let ((state (get-buffer-window pianobar-buffer)))
       (cond
        (state
@@ -171,7 +173,7 @@
 
 (defadvice pianobar-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
@@ -207,7 +209,7 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
 ;;;###autoload
 (defun emacspeak-pianobar  ()
   "Start or control Emacspeak Pianobar player."
-  (interactive )
+  (interactive)
   (declare (special pianobar-buffer))
   (condition-case nil
       (unless (featurep 'pianobar) (require 'pianobar))
@@ -287,7 +289,6 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
   (setq emacspeak-pianobar-current-preset (1- emacspeak-pianobar-current-preset))
   (pianobar-send-string (format "s%s\n" emacspeak-pianobar-current-preset)))
 
-
 ;;}}}
 
 (provide 'emacspeak-pianobar)
