@@ -58,58 +58,58 @@
    (t(save-excursion
        (end-of-line)
        (skip-syntax-backward "^ ")
-       (emacspeak-speak-line 1)))))
+       (emacspeak-speak-field)))))
 
 ;;}}}
 ;;{{{ Advice
 (defadvice tar-quit (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice tar-next-line (after emacspeak pre act comp)
   "Provide spoken feedback"
-  (when (ems-interactive-p  )
+  (when (ems-interactive-p)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-previous-line (after emacspeak pre act comp)
   "Provide spoken feedback"
-  (when (ems-interactive-p  )
+  (when (ems-interactive-p)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-flag-deleted (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-unflag (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-tar-speak-line)))
 (defadvice tar-unflag-backwards (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-extract (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice tar-extract-other-window (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice tar-view (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
