@@ -215,7 +215,7 @@ proc beep {{freq 523} {length 100}} {
     if {[info exists tts(beep)]
         && $tts(beep) == 1}  {
         set l  [expr $length / 1000.0]
-        exec play -q -n synth $l sin $freq &
+        exec play -q -n synth $l sin $freq fade p 0.01 0 &
     }
 }
 
